aboutsummaryrefslogtreecommitdiff
path: root/build2/b.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'build2/b.cxx')
-rw-r--r--build2/b.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/build2/b.cxx b/build2/b.cxx
index 8031559..d16a406 100644
--- a/build2/b.cxx
+++ b/build2/b.cxx
@@ -9,7 +9,7 @@
#include <sstream>
#include <cstring> // strcmp(), strchr()
#include <typeinfo>
-#include <iostream>
+#include <iostream> // cout
#include <butl/pager>
@@ -195,8 +195,8 @@ main (int argc, char* argv[])
//
return p.wait () ? 0 : 1;
}
// Catch ios_base::failure as std::system_error together with the
// pager-specific exceptions.
//
catch (const system_error& e)
{
@@ -273,7 +273,7 @@ main (int argc, char* argv[])
parser p;
bspec = p.parse_buildspec (is, path ("<buildspec>"));
}
- catch (const istringstream::failure&)
+ catch (const io_error&)
{
fail << "unable to parse buildspec '" << args << "'";
}
@@ -195,8 +195,8 @@ main (int argc, char* argv[])
return p.wait () ? 0 : 1;
}
- // Catch ios_base::failure as std::system_error together with the
- // pager-specific exceptions.
+ // Catch io_error as std::system_error together with the pager-specific
+ // exceptions.
//
catch (const system_error& e)